from numpy import *
from pylab import *

# Results for Lysozyme molecule

Nbem = array([30170,51386,96108,183852,277396,374726])
Nfem = array([97*65*97, 129*97*129, 161*129*161, 257*161*257, 385*257*385, 449*385*449,513*449*513])

elemPerAng  = array([2.7, 4.04, 7.7, 14.6, 22.4, 30.6])
Lbem = sqrt(1/elemPerAng)

Vfem = 50.*40.*50.
Lfem = (Vfem/Nfem)**(1/3.) 
Lfem_aux = array([[0.521,0.625,0.521],[0.391,0.417,0.391],
                  [0.312,0.312,0.312],[0.195,0.250,0.195],
                  [0.130,0.156,0.130],[0.112,0.104,0.112],
                  [0.098,0.089,0.098]])

#Lfem = average(Lfem_aux,axis=1)

# Number of iterations
iterationsPyG =array([37,38,41,45,49,49])

# Time
timePyG = array([28.16, 51.2, 86.4, 163.9, 256.2, 360.2])
timeAPB = array([4.3,8.6,17.7,54,161,352,768])

# Esolv
EsolvPyG = array([-2432.9, -2195.9, -2124.2, -2101.1, -2094.9, -2090.8])
EsolvAPB = array([-2237,-2172.9,-2142,-2121.5,-2102.6,-2093.7,-2090.7])
APB_ext = -2070.47
PyG_ext = -2082.5

font = {'family':'serif','size':7}
figure(figsize=(3,2), dpi=80)
rc('font',**font)

xmax = Nfem[-1]*5
xmin = Nbem[0]/1.5

semilogx(Nbem, EsolvPyG, c='k', marker='o', mfc='w', ms=3,ls='-',lw=0.5, label='PyGBe')
semilogx(Nfem, EsolvAPB, c='k', marker='^', mfc='w', ms=3,ls='-',lw=0.5, label='APBS')

semilogx([xmin,xmax],PyG_ext*ones(2), c='k', marker='', mfc='w', ms=1, ls='dotted',lw=0.2)
semilogx([xmin,xmax],APB_ext*ones(2), c='k', marker='', mfc='w', ms=1, ls='dotted',lw=0.2)
ylabel('$\Delta G_{solv}$ [kJ/mol]', fontsize=10)
xlabel('N',fontsize=10)
text(5e5, -2101,'PyGBe extrap.',fontsize=6,rotation=0)
text(1e7, -2067,'APBS extrap.',fontsize=6,rotation=0)
subplots_adjust(left=0.22, bottom=0.21, right=0.96, top=0.95)
axis([xmin,xmax,-2450,-2040])
legend(loc='lower right')
savefig('Esolv_lys.pdf')
clf()

APBerr = abs(EsolvAPB-APB_ext)/abs(APB_ext)
PyGerr = abs(EsolvPyG-PyG_ext)/abs(PyG_ext)
loglog(Nbem, PyGerr, c='k', marker='o', mfc='w', ms=3, ls='', lw=0.5, label='PyGBe')
loglog(Nfem, APBerr, c='k', marker='^', mfc='w', ms=3, ls='', lw=0.5, label='APBS')
loglog(Nbem, 1./Nbem*1e3, c='k', marker='', mfc='w', ms=3, ls=':', lw=0.8, label=None)
loglog(Nfem, 1./(Nfem)**(1./3)*4e0, c='k', marker='', mfc='w', ms=3, ls=':', lw=0.8, label=None)
text(2.5e4, 2.5e-2,'area',fontsize=6,rotation=-50)
text(7.0e5, 3.2e-2,'mesh spacing',fontsize=6,rotation=-21)
ylabel('Error', fontsize=10)
xlabel('N',fontsize=10)
subplots_adjust(left=0.22, bottom=0.21, right=0.96, top=0.95)
legend(loc='lower right')
savefig('Error_lys.pdf')
clf()

loglog(PyGerr, timePyG, c='k', marker='o', mfc='w', ms=5, ls='-',lw=0.5,label='PyGBe')
loglog(APBerr, timeAPB, c='k', marker='^', mfc='w', ms=5, ls='-',lw=0.5,label='APBS')
subplots_adjust(left=0.19, bottom=0.21, right=0.96, top=0.95)
ylabel('Time to solution [s]',fontsize=10)
xlabel('Error',fontsize=10)
legend(loc='lower left')
savefig('time_lys.pdf')
clf()
